@@ -587,12 +587,10 @@ class ComputeApiTests(test.APIMockTestCase):
         self.assertEqual(0, api_flavor.ephemeral)
         self.assertEqual(0, api_flavor.swap)
         self.assertTrue(api_flavor.is_public)
-        self.assertEqual(1, api_flavor.rxtx_factor)
 
         novaclient.flavors.create.assert_called_once_with(
             flavor.name, flavor.ram, flavor.vcpus, flavor.disk,
-            flavorid='auto', ephemeral=0, swap=0, is_public=True,
-            rxtx_factor=1)
+            flavorid='auto', ephemeral=0, swap=0, is_public=True)
 
     @mock.patch.object(api._nova, 'novaclient')
     def test_flavor_delete(self, mock_novaclient):
@@ -784,8 +782,13 @@ class ComputeApiTests(test.APIMockTestCase):
 
         self.assertIsInstance(ret, api.nova.Server)
         self.mock_get_microversion.assert_called_once_with(
-            mock.sentinel.request, ('multiattach', 'instance_description',
-                                    'auto_allocated_network'))
+            mock.sentinel.request, (
+                'multiattach',
+                'bdm2_volume_type',
+                'instance_description',
+                'auto_allocated_network',
+            )
+        )
         self.mock_novaclient.assert_called_once_with(
             mock.sentinel.request, version=mock.sentinel.microversion)
         novaclient.servers.create.assert_called_once_with(
